.. Python FTR documentation master file, created by
   sphinx-quickstart on Tue Mar 10 09:11:24 2015.

Content Extractor objects
=========================

.. automodule:: ftr.extractor
        :members:
